<?php

namespace ova_framework;

use ova_framework\widgets\ova_menu;
use ova_framework\widgets\ova_logo;
use ova_framework\widgets\ova_header;


use ova_framework\widgets\ova_contact_info;
use ova_framework\widgets\ova_search;
use ova_framework\widgets\ova_banner_slideshow;
use ova_framework\widgets\ova_blog_footer;
use ova_framework\widgets\ova_heading;
use ova_framework\widgets\ova_banner;
use ova_framework\widgets\ova_volunteer;
use ova_framework\widgets\ova_about_info;
use ova_framework\widgets\ova_give_donation;
use ova_framework\widgets\ova_give_donations;

use ova_framework\widgets\ova_blog;
use ova_framework\widgets\ova_icon;
use ova_framework\widgets\ova_feature;
use ova_framework\widgets\ova_map_campaign;
use ova_framework\widgets\ova_contact;
use ova_framework\widgets\ova_social;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly




/**
 * Main Plugin Class
 *
 * Register new elementor widget.
 *
 * @since 1.0.0
 */
class Ova_Register_Elementor {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
	}

	/**
	 * Add Actions
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 */
	private function add_actions() {

		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'add_hf_category' ) );

	     // Register Ovatheme Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'add_ovatheme_category' ) );
	    
		
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );
		

	}

	
	public  function add_hf_category(  ) {
	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'ova-framework' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	
	public function add_ovatheme_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'ovatheme',
	        [
	            'title' => __( 'Ovatheme', 'ova-framework' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}


	/**
	 * On Widgets Registered
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}

	/**
	 * Includes
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 */
	private function includes() {
		
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-menu.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-logo.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-header.php';

		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-contact-info.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-search.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-banner-slide.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-laster-new-footer.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-heading.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-banner.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-volunteer.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova-about-info.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_give_donation.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_give_donations.php';

		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_blog.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_icon.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_feature.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_map_campaign.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_contact.php';
		require OVA_PLUGIN_PATH . 'ova-elementor/widgets/ova_social.php';
		
	}

	/**
	 * Register Widget
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 */
	private function register_widget() {

		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_menu() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_logo() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_header() );


		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_contact_info() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_search() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_banner_slideshow() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_blog_footer() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_heading() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_banner() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_volunteer() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_about_info() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_give_donation() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_give_donations() );
		
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_blog() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_icon() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_feature() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_map_campaign() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_contact() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new ova_social() );
		
	}
	    
	

}

new Ova_Register_Elementor();





