<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_banner extends Widget_Base {

	public function get_name() {
		return 'ova_banner';
	}

	public function get_title() {
		return __( 'Volunter Banner', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-banner';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {
			
		$this->start_controls_section(
			'recommend_banner',
			[
				'label' => __('Content','ova-framework')
			]
		);
			$this->add_control(
				'type_banner',
				[
					'label' => __('Banner Style','ova-framework'),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'style_1' => __('Style 1', 'ova-framework'),
						'style_2' => __('Style 2', 'ova-framework'),
						'style_3' => __('Style 3', 'ova-framework')
					],
					'default' => 'style_1'
				]
			);

			$this->add_control(
				'recommend_banner_alignment',
				[
					'label'   => __( 'Alignment', 'ova-framework' ),
					'type'    => Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => __( 'Left', 'ova-framework' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'ova-framework' ),
							'icon'  => 'fa fa-align-center',
						],
						'right' => [
							'title' => __( 'Right', 'ova-framework' ),
							'icon'  => 'fa fa-align-right',
						],
					],
					'default' => 'center',
					'selectors' => [
						'{{WRAPPER}} .volunteer .volunteer-content' => 'text-align: {{VALUE}}',
					]
				]
			);

			$this->add_control(
				'background_banner',
				[
					'label' => __('Background','ova-framework'),
					'type'  => Controls_Manager::MEDIA,
				]				
			);

			$this->add_responsive_control(
				'padding_wrap_content',
				[
					'label'      => __( 'Padding', 'ova-framework' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .volunteer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'show_title',
				[
					'label'        => __( 'Show Title', 'ova-framework' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'ova-framework' ),
					'label_off'    => __( 'Hide', 'ova-framework' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				]
			);

			$this->add_control(
				'title_banner',
				[
					'label'     => __('Title','ova-framework'),
					'type'      => Controls_Manager::TEXT,
					'default'   => __('Become A Volunteer', 'ova-framework'),
					'condition' => [
						'show_title' => 'yes'
					]
				]
			);

			$this->add_control(
				'heading_size',
				[
					'label' => __( 'HTML Tag', 'elementor' ),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
					],
					'default' => 'h3',
					'condition' => [
						'show_title' => 'yes'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'      => 'title_banner_typography',
					'selector'  => '{{WRAPPER}} .volunteer-content .headding',
					'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
					'condition' => [
						'show_title' => 'yes'
					]
				]
			);

			$this->add_control(
				'title_banner_color',
				[
					'label'     => __('Title Color','ova-framework'),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .volunteer-content .headding' => 'color: {{VALUE}};'
					],
					'condition' => [
						'show_title' => 'yes'
					],
				]
			);

			$this->add_responsive_control(
				'padding_title',
				[
					'label'      => __( 'Padding', 'ova-framework' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .volunteer-content .headding' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'show_title' => 'yes'
					],
					'separator' => 'after',	
				]
			);

			$this->add_control(
				'show_content',
				[
					'label'        => __( 'Show Content', 'ova-framework' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'ova-framework' ),
					'label_off'    => __( 'Hide', 'ova-framework' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				]
			);

			$this->add_control(
				'content_banner',
				[
					'label'     => __('Content Text','ova-framework'),
					'type'      => Controls_Manager::TEXT,
					'default'   => __('Sodales ut eu sem integer vitae. Porttitor leo a diam sollicitudin tempor id eu nisl nunc. Ac felis donec et odio.', 'ova-framework'),
					'condition' => [
						'show_content' => 'yes'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'      => 'content_banner_typography',
					'selector'  => '{{WRAPPER}} .volunteer-content p',
					'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
					'condition' => [
						'show_content' => 'yes'
					]
				]
			);

			$this->add_control(
				'content_banner_color',
				[
					'label'     => __('Content Color','ova-framework'),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .volunteer-content p' => 'color: {{VALUE}};'
					],
					'condition' => [
						'show_content' => 'yes'
					]
				]
			);

			$this->add_responsive_control(
				'padding_content',
				[
					'label'      => __( 'Padding', 'ova-framework' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .volunteer-content .headding' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'show_content' => 'yes'
					],
					'separator' => 'after',	
				]
			);

			$this->add_control(
				'show_button',
				[
					'label'        => __( 'Show Button', 'ova-framework' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'ova-framework' ),
					'label_off'    => __( 'Hide', 'ova-framework' ),
					'return_value' => 'yes',
					'default'      => 'yes',
				]
			);

			$this->add_control(
				'button_banner',
				[
					'label'     => __('Button','ova-framework'),
					'type'      => Controls_Manager::TEXT,
					'default'   => __('Join With Us','ova-framework'),
					'condition' => [
						'show_button' => 'yes'
					]
				]
			);

			$this->add_control(
				'button_banner_link',
				[
					'label' => __( 'Link to', 'ova-framework' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => __( 'https://your-link.com', 'ova-framework' ),
					'condition' => [
						'show_button' => 'yes'
					]
				]
			);

			$this->start_controls_tabs( 'tabs_button_style' );
				$this->start_controls_tab(
					'tab_button_normal',
					[
						'label' => __( 'Normal', 'ova-framework' ),
					]
				);

				$this->add_control(
					'button_control_text_color',
					[
						'label'     => __( 'Text Color', 'ova-framework' ),
						'type'      => Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer' => 'color: {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'button_control_background_color',
					[
						'label'     => __( 'Background Color', 'ova-framework' ),
						'type'      => Controls_Manager::COLOR,
						'default'   => '',
						'selectors' => [
							'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer' => 'background-color: {{VALUE}};',
						],
					]
				);

				$this->end_controls_tab();

				// Tab button hover
				$this->start_controls_tab(
					'tab_button_hover',
					[
						'label' => __( 'Hover', 'ova-framework' ),
					]
				);

					$this->add_control(
						'button_control_hover_color',
						[
							'label'     => __( 'Text Color', 'ova-framework' ),
							'type'      => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer:hover' => 'color: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_control_background_hover_color',
						[
							'label'     => __( 'Background Color', 'ova-framework' ),
							'type'      => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer:hover' => 'background-color: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_hover_border_color',
						[
							'label'     => __( 'Border Color', 'ova-framework' ),
							'type'      => Controls_Manager::COLOR,
							'condition' => [
								'border_border!' => '',
							],
							'selectors' => [
								'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer:hover' => 'border-color: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'button_box_shadow',
							'selector' => '{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer',
						]
					);

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name'        => 'border',
					'placeholder' => '1px',
					'default'     => '1px',
					'selector'    => '{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer',
					'separator'   => 'before',
				]
			);

			$this->add_control(
				'border_radius',
				[
					'label'      => __( 'Border Radius', 'ova-framework' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_button',
				[
					'label'      => __( 'Padding', 'ova-framework' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .volunteer .volunteer-content .btn-volunteer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'show_button' => 'yes'
					],
					'separator' => 'before',
				]
			);

		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings();

		$background_banner  = $settings['background_banner']['url'];
		$title_banner       = $settings['title_banner'];
		$content_banner     = $settings['content_banner'];
		$button_banner_text = $settings['button_banner'];

		$title_html = sprintf( '<%1$s class="headding second_font">%2$s</%1$s>', $settings['heading_size'], $title_banner );

		if ( ! empty( $settings['button_banner_link']['url'] ) ) {
			$this->add_render_attribute( 'button_banner_link', 'href', $settings['button_banner_link']['url'] );

			if ( $settings['button_banner_link']['is_external'] ) {
				$this->add_render_attribute( 'button_banner_link', 'target', '_blank' );
			}

			if ( ! empty( $settings['button_banner_link']['nofollow'] ) ) {
				$this->add_render_attribute( 'button_banner_link', 'rel', 'nofollow' );
			}
		} else{
			$this->add_render_attribute( 'button_banner_link', 'href', '#' );
		}


		?>

		<div class="volunteer <?php echo esc_attr( $settings['type_banner'] ); ?>" <?php if($background_banner != '') : ?>style="background-image: url(<?php echo esc_url($background_banner); ?>)" <?php endif;?>>
			<div class="container">
				<div class="volunteer-content">

					<?php if( $settings['show_title'] === 'yes' && $title_banner != ''){ ?>
						<?php echo $title_html; ?>
					<?php } ?>
					<?php if( $settings['show_content'] === 'yes' && $content_banner != ''){ ?> 
						<p><?php echo esc_html( $content_banner );?></p>
					<?php } ?>
					<?php if( $settings['show_button'] === 'yes' && $button_banner_text != '' ){?>
						<a <?php echo $this->get_render_attribute_string('button_banner_link');?> class="btn-volunteer second_font"><?php echo esc_html($button_banner_text);?></a>
					<?php } ?>
					
				</div>
			</div>
		</div>

	<?php }

}


