<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use WP_Query;
use Give_Donate_Form;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_give_donation extends Widget_Base {

	public function get_name() {
		return 'ova_give_donation';
	}

	public function get_title() {
		return __( 'Give Donation', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-price-list';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_image',
			[
				'label' => __( 'Image', 'ova-framework' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);

		$this->end_controls_section();
		/***** End Image Section *****/

		$this->start_controls_section(
			'section_content_subtitle',
			[
				'label' => __( 'Sub Title', 'ova-framework' ),
			]
		);

		$this->add_control(
			'text_sub_title',
			[
				'label' => __( 'Text', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Popular Couses',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typo_subtitle',
				'selector' => '{{WRAPPER}} .element_give_donation .content .sub_title ',
			]
		);

		$this->add_control(
			'color_subtitle',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .sub_title ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_subtitle',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .sub_title ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		/***** End Sub Title Section *****/


		/***** Title Section *****/
		$this->start_controls_section(
			'section_content_title',
			[
				'label' => __( 'Title', 'ova-framework' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typo_title',
				'selector' => '{{WRAPPER}} .element_give_donation .content .title a ',
			]
		);

		$this->add_control(
			'color_title',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .title a ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'color_title_hover',
			[
				'label' => __( 'Color Hover', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .title a:hover ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_title',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .title a ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		/***** End Title Section *****/


		/***** Description Section *****/
		$this->start_controls_section(
			'section_content_desc',
			[
				'label' => __( 'Description', 'ova-framework' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typo_desc',
				'selector' => '{{WRAPPER}} .element_give_donation .content .desc ',
			]
		);

		$this->add_control(
			'color_desc',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .desc ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_desc',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .desc ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		/***** End Description Section *****/

		/***** Progress Section *****/
		$this->start_controls_section(
			'section_progress',
			[
				'label' => __( 'Progress', 'ova-framework' ),
			]
		);

		$this->add_control(
			'show_progress',
			[
				'label' => __( 'Show Progress', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'ova-framework' ),
				'label_off' => __( 'Hide', 'ova-framework' ),
				'default' => 'no',
			]
		);

		$this->add_control(
			'color_progress',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .progress .text, {{WRAPPER}} .element_give_donation .progress .number ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		/***** End Progress Section *****/


		/***** Raised Section *****/
		$this->start_controls_section(
			'section_raised',
			[
				'label' => __( 'Raised', 'ova-framework' ),
			]
		);

		$this->add_control(
			'number_raised_heading',
			[
				'label' => __( 'Number', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'color_number_raised',
			[
				'label' => __( 'Color Number', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .raised .number ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_raised_typography',
				'label' => __( 'Typography', 'ova-framework' ),
				'selector' => '{{WRAPPER}} .element_give_donation .raised .number ',
			]
		);

		$this->add_control(
			'text_raised_heading',
			[
				'label' => __( 'Text', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'color_text_raised',
			[
				'label' => __( 'Color Text', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .raised .text ' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_raised_typography',
				'label' => __( 'Typography', 'ova-framework' ),
				'selector' => '{{WRAPPER}} .element_give_donation .raised .text ',
			]
		);

		$this->end_controls_section();
		/***** End Raised Section *****/


		/***** End Donate Section *****/
		$this->start_controls_section(
			'section_content_donate',
			[
				'label' => __( 'Donate', 'ova-framework' ),
			]
		);

		$this->add_control(
			'text_donate',
			[
				'label' => __( 'Text', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Donate Now',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typo_donate',
				'selector' => '{{WRAPPER}} .element_give_donation .content .button_donate ',
			]
		);

		$this->add_responsive_control(
			'padding_donate',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'tabs_donate_style' );

		$this->start_controls_tab(
			'tab_donate_normal',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);

		$this->add_control(
			'donate_text_color',
			[
				'label' => __( 'Text Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'donate_background_color',
			[
				'label' => __( 'Background Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'donate_border_color',
			[
				'label' => __( 'Border Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_donate_hover',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);

		$this->add_control(
			'donate_hover_color',
			[
				'label' => __( 'Text Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'donate_background_hover_color',
			[
				'label' => __( 'Background Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'donate_hover_border_color',
			[
				'label' => __( 'Border Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donation .content .button_donate a:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();


		$this->end_controls_section();
		/***** End Donate Section *****/

	}

	protected function render() {
		$settings = $this->get_settings();

		$text_donate = $settings['text_donate'];
		$sub_title = $settings['text_sub_title'];
		$image = $settings['image']['url'];
		$show_progress = $settings['show_progress'];

		$paged   = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$args_base = array(
			'post_type' => 'give_forms',
			'posts_per_page' => '1'
		);
		$give_donation = new WP_Query( $args_base );

		if(in_array('give/give.php', apply_filters('active_plugins', get_option('active_plugins')))) {
			?>
			<div class="container">
				
				<div class="element_give_donation">

					<?php if($give_donation->have_posts() ) : while ( $give_donation->have_posts() ) : $give_donation->the_post(); ?>
						<?php
						$id = get_the_ID();

						$ova_met_gallery_give = get_post_meta( $id, 'ova_met_gallery_give', true ) ? get_post_meta( $id, 'ova_met_gallery_give', true ) : '';
						$ova_met_media_give = get_post_meta( $id, 'ova_met_media_give', true ) ? get_post_meta( $id, 'ova_met_media_give', true ) : 'javascript:;';

						$show_goal = give_get_meta( $id, '_give_goal_option', true );
						$charihope_progress_stats = apply_filters( 'charihope_progress_stats', $id );

						$end_date = get_post_meta( $id, 'ova_met_end_date_give', true ) ? get_post_meta( $id, 'ova_met_end_date_give', true ) : '0';

						$interval = intval($end_date) - time();

						$days_left = floor($interval / (60 * 60 * 24)) +1;

						$charihope_count_donor = apply_filters( 'charihope_count_donor', $id);

						?>
						<div class="image_future">
							<div class="thumbnail">
								<?php if ($image == '') { 
									the_post_thumbnail(); 
								} else { ?>
									<img src="<?php echo esc_attr($image) ?>" alt="#">
								<?php } ?>

								<div class="media">
									<ul style="display: none;">
										<?php if ( $ova_met_gallery_give ) {
											foreach ( $ova_met_gallery_give as $key => $value ) { ?>
												<li><a href="<?php echo esc_attr( $value ); ?>" data-fancybox="<?php echo esc_attr( $id ); ?>"><img src="<?php echo esc_attr( $value ); ?>" alt="<?php echo esc_attr( $key ); ?>"></a></li>
											<?php }
										} ?>
									</ul>
									<a href="javascript:;" data-fancybox-trigger="<?php echo esc_attr( $id ); ?>" class="gallery"><i class="icon_images"></i></a>
									<a href="<?php echo esc_attr( $ova_met_media_give ); ?>" data-fancybox="<?php echo esc_attr( $ova_met_media_give ); ?>" class="video"><i class="icon_film"></i></a>
								</div>
							</div>
						</div>

						<div class="content">
							<p class="sub_title"><?php echo esc_html($sub_title); ?></p>
							<h3 class="second_font title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

							<p class="desc"><?php echo esc_html( get_the_excerpt() ); ?></p>

							<?php if ($show_goal != 'disabled') { ?>
								<div class="progress">
									<span class="wrap_percentage" style="width: <?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?>; ">
										<?php if ($show_progress == 'yes') { ?>
											<span class="text second_font"><?php esc_html_e( 'Donated:', 'ova-framework' ); ?></span>
											<?php if ($charihope_progress_stats['progress'] < '95') { ?>
												<span class="number second_font"><?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?></span>
											<?php } else { ?>
												<span class="number second_font fix"><?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?></span>
											<?php } ?>
										<?php } ?>
									</span>
								</div>

							<?php } ?>

							<div class="raised">
								<div class="income">
									<span class="second_font number"><?php echo esc_html( $charihope_progress_stats['actual'] ); ?></span>
									<span class="text"><?php esc_html_e( 'Raised', 'charihope' ); ?></span>
								</div>

								<?php if ($show_goal != 'disabled') { ?>
									<div class="goal">
										<span class="second_font number"><?php echo esc_html( $charihope_progress_stats['goal'] ); ?></span>
										<span class="text"><?php esc_html_e( 'Goal', 'charihope' ); ?></span>
									</div>
								<?php } ?>

								<div class="donor">
									<span class="second_font number"><?php echo esc_html( $charihope_count_donor ); ?></span>
									<span class="text"><?php esc_html_e( 'Donor', 'charihope' ); ?></span>
								</div>
							</div>

							<div class="button_donate">
								<a href="<?php the_permalink(); ?>" class="second_font "><?php echo esc_html($text_donate); ?></a>
							</div>
						</div>
					<?php endwhile; 
					else: ?>
						<div class="search_not_found">
							<?php esc_html_e( 'Not Found Give Donation', 'charihope' ); ?>
						</div>

					<?php endif; wp_reset_postdata(); wp_reset_query(); ?>

				</div>
			</div>

			<?php
		} else {
			esc_html_e( 'Please active plugins Give Donations', 'ova-framework' );;
		}
	}
}
?>