<?php

namespace ova_framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use WP_Query;
use Give_Donate_Form;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class ova_give_donations extends Widget_Base {

	public function get_name() {
		return 'ova_give_donations';
	}

	public function get_title() {
		return __( 'Give Donations', 'ova-framework' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		/***** Layout Section *****/
		$this->start_controls_section(
			'section_layout',
			[
				'label' => __( 'Layout', 'ova-framework' ),
			]
		);

		$this->add_control(
			'number_items',
			[
				'label' => __( 'Number Items', 'ova-framework' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->add_control(
			'layout_columns',
			[
				'label' => __( 'Columns', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '3',
				'options' => [
					'2'  => __( '2 Columns', 'ova-framework' ),
					'3' => __( '3 Columns', 'ova-framework' ),
				],
			]
		);

		$this->add_control(
			'layout_show_post',
			[
				'label' => __( 'Show Post', 'ova-framework' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'ova-framework' ),
					'feature' => __( 'Feature', 'ova-framework' ),
				],
			]
		);


		$this->end_controls_section();
		/***** End Layout Section *****/


		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'ova-framework' ),
			]
		);

		$this->add_control(
			'text_donate',
			[
				'label' => __( 'Text Donate', 'ova-framework' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Donate Now',
			]
		);

		$this->end_controls_section();
		/***** End Content Section *****/


		/***** Style Section *****/
		$this->start_controls_section(
			'content_style',
			[
				'label' => __( 'Content', 'ova-framework' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .element_give_donations .archive_give_donation .donate_remaining .donate',
			]
		);

		$this->add_control(
			'color_content',
			[
				'label' => __( 'Color', 'ova-framework' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .element_give_donations .archive_give_donation .donate_remaining .donate' => 'color : {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'padding_content',
			[
				'label' => __( 'Padding', 'ova-framework' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .element_give_donations .archive_give_donation .donate_remaining .donate' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		$text_donate = $settings['text_donate'];
		$layout_columns = $settings['layout_columns'];
		$number_items = $settings['number_items'];

		if ($settings['layout_show_post'] != '') {
			$layout_show_post = array(
				array(
					'key' => 'ova_met_feature_give',
					'value' => 'on',
					'compare' => '=',
				)
			);
		} else {
			$layout_show_post = '';
		};

		$paged   = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$args_base = array(
			'post_type' => 'give_forms',
			'posts_per_page' => $number_items,
			'meta_query' => $layout_show_post,
		);

		$give_donation = new WP_Query( $args_base );
		if(in_array('give/give.php', apply_filters('active_plugins', get_option('active_plugins')))) {
			?>
			<div class="element_give_donations">

				<div class="archive_give_donation">
					<div class="summary">
						<div class="wrap_summary <?php echo 'column_'.esc_attr($layout_columns); ?>">
							<?php if($give_donation->have_posts() ) : while ( $give_donation->have_posts() ) : $give_donation->the_post(); ?>
								<?php
								$id = get_the_ID();

								$ova_met_gallery_give = get_post_meta( $id, 'ova_met_gallery_give', true ) ? get_post_meta( $id, 'ova_met_gallery_give', true ) : '';
								$ova_met_media_give = get_post_meta( $id, 'ova_met_media_give', true ) ? get_post_meta( $id, 'ova_met_media_give', true ) : 'javascript:;';

								$show_goal = give_get_meta( $id, '_give_goal_option', true );
								$charihope_progress_stats = apply_filters( 'charihope_progress_stats', $id );

								$end_date = get_post_meta( $id, 'ova_met_end_date_give', true ) ? get_post_meta( $id, 'ova_met_end_date_give', true ) : '0';

								$interval = intval($end_date) - time();

								$days_left = floor($interval / (60 * 60 * 24)) +1;

								$charihope_count_donor = apply_filters( 'charihope_count_donor', $id);

								?>
								<div class="give_detail">

									<div class="image_future">
										<div class="thumbnail">
											<?php the_post_thumbnail(); ?>
										</div>

										<div class="media">
											<ul style="display: none;">
												<?php if ( $ova_met_gallery_give ) {
													foreach ( $ova_met_gallery_give as $key => $value ) { ?>
														<li><a href="<?php echo esc_attr( $value ); ?>" data-fancybox="<?php echo esc_attr( $id ); ?>"><img src="<?php echo esc_attr( $value ); ?>" alt="<?php echo esc_attr( $key ); ?>"></a></li>
													<?php }
												} ?>
											</ul>
											<a href="javascript:;" data-fancybox-trigger="<?php echo esc_attr( $id ); ?>" class="gallery"><i class="icon_images"></i></a>
											<a href="<?php echo esc_attr( $ova_met_media_give ); ?>" class="video"><i class="icon_film"></i></a>
										</div>

										<?php if ($show_goal != 'disabled') { ?>
											<div class="progress">
												<?php if ($charihope_progress_stats['progress'] < '50') { ?>
													<span class="wrap_percentage_1" style="width: <?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?>; ">
														<span class="percentage"><?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?></span>
													</span>
												<?php } elseif ( $charihope_progress_stats['progress'] >= '50') { ?>
													<span class="wrap_percentage_2" style="width: <?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?>; ">
														<span class="percentage"><?php echo esc_attr( $charihope_progress_stats['progress'].'%' ); ?></span>
													</span>
												<?php } ?>

											</div>
										<?php } ?>
									</div>
									
									<div class="detail_body">

										<h3 class="second_font title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

										<p class="desc"><?php echo esc_html( get_the_excerpt() ); ?></p>

										<div class="donate_remaining">
											<a href="<?php the_permalink(); ?>" class="donate second_font"><?php echo esc_html( $text_donate ); ?></a>

											<?php if ($days_left > 0) { ?>
												<?php if ($days_left == '1' ) { ?>
													<div class="time_remaining">
														<?php esc_html_e( $days_left .' day left', 'ova-framework' ); ?>
													</div>
												<?php } else {?>
													<div class="time_remaining">
														<?php esc_html_e( $days_left .' days left', 'ova-framework' ); ?>
													</div>
												<?php } ?>

											<?php } elseif ($days_left == 0) { ?>
												<div class="time_remaining">
													<?php esc_html_e( 'In day', 'ova-framework' ); ?>
												</div>
											<?php } else { ?>
												<div class="time_remaining">
													<?php esc_html_e( 'Close', 'ova-framework' ); ?>
												</div>
											<?php } ?>
										</div>

										<div class="raised">
											<div class="income">
												<span class="second_font"><?php esc_html_e( 'Raised', 'ova-framework' ); ?></span>
												<span><?php echo esc_html( $charihope_progress_stats['actual'] ); ?></span>
											</div>

											<?php if ($show_goal != 'disabled') { ?>
												<div class="goal">
													<span class="second_font"><?php esc_html_e( 'Goal', 'ova-framework' ); ?></span>
													<span><?php echo esc_html( $charihope_progress_stats['goal'] ); ?></span>
												</div>
											<?php } ?>

											<div class="donor">
												<span class="second_font"><?php esc_html_e( 'Donor', 'ova-framework' ); ?></span>
												<span><?php echo esc_html( $charihope_count_donor ); ?></span>
											</div>
										</div>
									</div>
								</div>
							<?php endwhile; 
							else: ?>
								<div class="search_not_found">
									<?php esc_html_e( 'Not Found Give Donation', 'ova-framework' ); ?>
								</div>

							<?php endif; wp_reset_postdata(); wp_reset_query(); ?>
						</div>
					</div>
				</div>
			</div>

			<?php
		} else {
			esc_html_e( 'Please active plugins Give Donations', 'ova-framework' );;
		}
	}
}
?>